==> audiochain-1.1.5-src.tgz: org/audiochain/model/AbstractCommandLineUserInterface.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.model;

import java.util.Collection;
import java.util.Formatter;
import java.util.LinkedHashSet;

public abstract class AbstractCommandLineUserInterface implements CommandLineUserInterface {
	private Collection<CommandLineUserInterfaceListener> listeners;

	protected final void fireCommandLineUserInterfaceUpdate() {
		if (listeners == null) {
			return;
		}
		for (CommandLineUserInterfaceListener listener : new LinkedHashSet<CommandLineUserInterfaceListener>(listeners)) {
			listener.commandLineUserInterfacePerformanceDisplayStringUpdate(this);
		}
	}

	@Override
	public final void addCommandLineUserInterfaceListener(CommandLineUserInterfaceListener listener) {
		if (listeners == null) {
			listeners = new LinkedHashSet<CommandLineUserInterfaceListener>();
		}
		listeners.add(listener);
	}

	@Override
	public final void removeCommandLineUserInterfaceListener(CommandLineUserInterfaceListener listener) {
		if (listeners == null) {
			return;
		}
		listeners.remove(listener);
		if (listeners.isEmpty()) {
			listeners = null;
		}
	}
	
	@Override
	public String getPerformanceDisplayString() {
		return null;
	}
	
	protected static final String format(String propertyName, String helpString) {
		StringBuilder sb = new StringBuilder();
		Formatter format = new Formatter(sb);
		format.format(HELP_FORMAT, propertyName, helpString);
		return sb.toString();
	}
	
	protected static final String format(String propertyName, String defaultValue, String optionsAndRanges) {
		StringBuilder sb = new StringBuilder();
		Formatter format = new Formatter(sb);
		format.format(HELP_FORMAT_WITH_DEFAULT_VALUE, propertyName, defaultValue, optionsAndRanges);
		return sb.toString();
	}

}

==> audiochain-1.1.6-src.tgz: org/audiochain/model/AbstractCommandLineUserInterface.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.model;

import java.util.Collection;
import java.util.Formatter;
import java.util.LinkedHashSet;

public abstract class AbstractCommandLineUserInterface implements CommandLineUserInterface {
	private Collection<CommandLineUserInterfaceListener> listeners;

	protected final void fireCommandLineUserInterfaceUpdate() {
		if (listeners == null) {
			return;
		}
		for (CommandLineUserInterfaceListener listener : new LinkedHashSet<CommandLineUserInterfaceListener>(listeners)) {
			listener.commandLineUserInterfacePerformanceDisplayStringUpdate(this);
		}
	}

	@Override
	public final void addCommandLineUserInterfaceListener(CommandLineUserInterfaceListener listener) {
		if (listeners == null) {
			listeners = new LinkedHashSet<CommandLineUserInterfaceListener>();
		}
		listeners.add(listener);
	}

	@Override
	public final void removeCommandLineUserInterfaceListener(CommandLineUserInterfaceListener listener) {
		if (listeners == null) {
			return;
		}
		listeners.remove(listener);
		if (listeners.isEmpty()) {
			listeners = null;
		}
	}
	
	@Override
	public String getPerformanceDisplayString() {
		return null;
	}
	
	protected static final String format(String propertyName, String helpString) {
		StringBuilder sb = new StringBuilder();
		Formatter format = new Formatter(sb);
		format.format(HELP_FORMAT, propertyName, helpString);
		String ret = sb.toString();
		format.close();
		return ret;
	}
	
	protected static final String format(String propertyName, String defaultValue, String optionsAndRanges) {
		StringBuilder sb = new StringBuilder();
		Formatter format = new Formatter(sb);
		format.format(HELP_FORMAT_WITH_DEFAULT_VALUE, propertyName, defaultValue, optionsAndRanges);
		String ret = sb.toString();
		format.close();
		return ret;
	}

}
